Enumeration

PurpleConversationType

unstable since: 3.0

Declaration

enum Purple.ConversationType

Description [src]

There are many different types of conversations in modern chat and this enumeration tries to cover them as best as possible.

If you have a need for one that doesn’t exist, please let us know and/or use UNSET for the time being.

Available since: 3.0

Members

PURPLE_CONVERSATION_TYPE_UNSET

A value to specify that the property has not been set or doesn’t match any of the other types.

  • Value: 0
  • Available since: 3.0
PURPLE_CONVERSATION_TYPE_DM

A direct message between two contacts.

  • Value: 1
  • Available since: 3.0
PURPLE_CONVERSATION_TYPE_GROUP_DM

A direct message between a protocol dependent number of contacts.

  • Value: 2
  • Available since: 3.0
PURPLE_CONVERSATION_TYPE_CHANNEL

A multi-user chat that is available to all users on the protocol and has features like moderation.

  • Value: 3
  • Available since: 3.0
PURPLE_CONVERSATION_TYPE_THREAD

A thread is a subset of messages from a conversation that are related.

  • Value: 4
  • Available since: 3.0
PURPLE_CONVERSATION_TYPE_COLLECTION

A collection of conversations with no restrictions on what type of conversations which is managed by the libpurple user and typically not published to the protocol.

  • Value: 5
  • Available since: 3.0
PURPLE_CONVERSATION_TYPE_SPACE

A collection of conversations similar to the collection type, but is managed by the protocol which means it should only have conversations with the same account.

  • Value: 6
  • Available since: 3.0